@@ -109,15 +109,12 @@ sub get_brain {
     my $storage = $self->storage;
     my $brainrs = $self->brain;
 
-    given ($storage) {
-        when ('MySQL') {
-            my $name = $self->tmpfile->[1];
-            $name =~ s[[^A-Za-z]][_]g;
-            return $name;
-        }
-        default {
-            return $self->brain // $self->tmpfile->[1];
-        }
+    if ($storage eq 'MySQL') {
+        my $name = $self->tmpfile->[1];
+        $name =~ s[[^A-Za-z]][_]g;
+        return $name;
+    } else {
+        return $self->brain // $self->tmpfile->[1];
     }
 }
 
@@ -137,27 +134,24 @@ sub spawn_storage {
         return if !try_load_class($pkg);
     }
 
-    given ($storage) {
-        when ('PostgreSQL') {
-            plan skip_all => "You must set TEST_POSTGRESQL= and have permission to createdb(1) to test PostgreSQL" unless $ENV{TEST_POSTGRESQL};
+    if ($storage eq 'PostgreSQL') {
+        plan skip_all => "You must set TEST_POSTGRESQL= and have permission to createdb(1) to test PostgreSQL" unless $ENV{TEST_POSTGRESQL};
 
-            # It doesn't use the file to store data obviously, it's just a convenient random token.
-            if (system "createdb '$brainrs' >/dev/null 2>&1") {
-                $ok = 0;
-            } else {
-                $self->{_created_pg} = 1;
-                # Kill Pg notices
-                no warnings; # Bizarre "Variable "$_" is not available" warning for the following line
-                $SIG{__WARN__} = sub { print STDERR @_ if $_[0] !~ m/NOTICE:\s*CREATE TABLE/; };
-            }
-        }
-        when ('MySQL') {
-            plan skip_all => "You must set TEST_MYSQL= and MYSQL_ROOT_PASSWORD= to test MySQL" unless $ENV{TEST_MYSQL} and $ENV{MYSQL_ROOT_PASSWORD};
-            system qq[echo "CREATE DATABASE $brainrs;" | mysql -u root -p$ENV{MYSQL_ROOT_PASSWORD}] and die $!;
-            system qq[echo "GRANT ALL ON $brainrs.* TO hailo\@localhost IDENTIFIED BY 'hailo';;" | mysql -u root -p$ENV{MYSQL_ROOT_PASSWORD}] and die $!;
-            system qq[echo "FLUSH PRIVILEGES;" | mysql -u root -p$ENV{MYSQL_ROOT_PASSWORD}] and die $!;
-            $self->{_created_mysql} = 1;
+        # It doesn't use the file to store data obviously, it's just a convenient random token.
+        if (system "createdb '$brainrs' >/dev/null 2>&1") {
+            $ok = 0;
+        } else {
+            $self->{_created_pg} = 1;
+            # Kill Pg notices
+            no warnings; # Bizarre "Variable "$_" is not available" warning for the following line
+            $SIG{__WARN__} = sub { print STDERR @_ if $_[0] !~ m/NOTICE:\s*CREATE TABLE/; };
         }
+    } elsif ($storage eq 'MySQL') {
+        plan skip_all => "You must set TEST_MYSQL= and MYSQL_ROOT_PASSWORD= to test MySQL" unless $ENV{TEST_MYSQL} and $ENV{MYSQL_ROOT_PASSWORD};
+        system qq[echo "CREATE DATABASE $brainrs;" | mysql -u root -p$ENV{MYSQL_ROOT_PASSWORD}] and die $!;
+        system qq[echo "GRANT ALL ON $brainrs.* TO hailo\@localhost IDENTIFIED BY 'hailo';;" | mysql -u root -p$ENV{MYSQL_ROOT_PASSWORD}] and die $!;
+        system qq[echo "FLUSH PRIVILEGES;" | mysql -u root -p$ENV{MYSQL_ROOT_PASSWORD}] and die $!;
+        $self->{_created_mysql} = 1;
     }
 
     return $ok;
@@ -173,20 +167,16 @@ sub unspawn_storage {
         $self->hailo->_storage->dbh->disconnect;
     };
 
-    given ($storage) {
-        when ('PostgreSQL') {
-            if ($self->{_created_pg}) {
-                $nuke_db->();
-                system "dropdb '$brainrs'";
-            }
-        }
-        when ('SQLite') {
+    if ($storage eq 'PostgreSQL') {
+        if ($self->{_created_pg}) {
             $nuke_db->();
+            system "dropdb '$brainrs'";
         }
-        when ('MySQL') {
-            if ($self->{_created_mysql}) {
-                system qq[echo "DROP DATABASE $brainrs;" | mysql -u root -p$ENV{MYSQL_ROOT_PASSWORD}] and die $!;
-            }
+    } elsif ($storage eq 'SQLite') {
+        $nuke_db->();
+    } elsif ($storage eq 'MySQL') {
+        if ($self->{_created_mysql}) {
+            system qq[echo "DROP DATABASE $brainrs;" | mysql -u root -p$ENV{MYSQL_ROOT_PASSWORD}] and die $!;
         }
     }
 }
@@ -197,32 +187,28 @@ sub _connect_opts {
 
     my %opts;
 
-    given ($storage) {
-        when ('SQLite') {
-            %opts = (
-                brain => ($self->in_memory  ? ':memory:' : $self->get_brain),
-                storage_args => {
-                    in_memory => 0,
-                },
-            );
-        }
-        when ('PostgreSQL') {
-            %opts = (
-                storage_args => {
-                    dbname => $self->get_brain
-                },
-            );
-        }
-        when ('MySQL') {
-            %opts = (
-                storage_args => {
-                    database => $self->get_brain,
-                    host => 'localhost',
-                    username => 'root',
-                    password => $ENV{MYSQL_ROOT_PASSWORD},
-                },
-            );
-        }
+    if ($storage eq 'SQLite') {
+        %opts = (
+            brain => ($self->in_memory  ? ':memory:' : $self->get_brain),
+            storage_args => {
+                in_memory => 0,
+            },
+        );
+    } elsif ($storage eq 'PostgreSQL') {
+        %opts = (
+            storage_args => {
+                dbname => $self->get_brain
+            },
+        );
+    } elsif ($storage eq 'MySQL') {
+        %opts = (
+            storage_args => {
+                database => $self->get_brain,
+                host => 'localhost',
+                username => 'root',
+                password => $ENV{MYSQL_ROOT_PASSWORD},
+            },
+        );
     }
 
     my %all_opts = (
@@ -342,9 +328,9 @@ sub train_filename {
     my $lns     = $lines // count_lines($filename);
 
     for my $l (1 .. $lns) {
-        chomp(my $_ = <$fh>);
-        pass("$storage: Training line $l/$lns of $filename: $_");
-        $hailo->learn($_);
+        chomp(my $line = <$fh>);
+        pass("$storage: Training line $l/$lns of $filename: $line");
+        $hailo->learn($line);
     }
 }
 
